@@ -11,7 +11,6 @@ package Term::ANSIEncode;
 #                     Written By Richard Kelsch                       #
 #                  © Copyright 2025 Richard Kelsch                    #
 #                        All Rights Reserved                          #
-#                           Version 1.06                              #
 #######################################################################
 # This program is free software: you can redistribute it and/or       #
 # modify it under the terms of the GNU General Public License as      #
@@ -34,6 +33,7 @@ use Term::ANSIScreen qw( :cursor :screen );
 use Term::ANSIColor;
 use Time::HiRes qw( sleep );
 use utf8;
+use charnames();
 use constant {
     TRUE  => 1,
     FALSE => 0,
@@ -44,7 +44,7 @@ use constant {
 binmode(STDOUT, ":encoding(UTF-8)");
 
 BEGIN {
-	our $VERSION = '1.05';
+	our $VERSION = '1.08';
 }
 
 sub ansi_output {
@@ -61,7 +61,10 @@ sub ansi_output {
                 $text =~ s/\[\%\s+$string\s+\%\]/$self->{'ansi_sequences'}->{$string}/gi;
             }
         } ## end foreach my $string (keys %{...})
-    } ## end if (length($text) > 1)
+        foreach my $string (keys %{ $self->{'characters'} }) {
+			$text =~ s/\[\%\s+$string\s+\%\]/$self->{'characters'}->{$string}/gi;
+        }
+    }
     my $s_len = length($text);
     my $nl    = $self->{'ansi_sequences'}->{'NEWLINE'};
     my $found = FALSE;
@@ -177,191 +180,24 @@ sub new {
         'BRIGHT B_CYAN'    => $esc . '106m',
         'BRIGHT B_WHITE'   => $esc . '107m',
 
-        'EURO'                             => '€',
-        'ELIPSIS'                          => '…',
-        'BULLET DOT'                       => chr(149),
-        'HOLLOW BULLET DOT'                => '○',
-        'BIG HYPHEN'                       => chr(150),
-        'BIGGEST HYPHEN'                   => chr(151),
-        'TRADEMARK'                        => '™',
-        'CENTS'                            => '¢',
-        'POUND'                            => '£',
-        'YEN'                              => '¥',
-        'COPYRIGHT'                        => '©',
-        'DOUBLE LT'                        => chr(171),
-        'REGISTERED'                       => '®',
-        'OVERLINE'                         => chr(175),
-        'DEGREE'                           => '°',
-        'SQUARED'                          => chr(178),
-        'CUBED'                            => chr(179),
-        'MICRO'                            => chr(181),
-        'PARAGRAPH'                        => chr(182),
-        'MIDDLE DOT'                       => chr(183),
-        'SUPERSCRIPT ONE'                  => chr(185),
-        'SUPERSCRIPT TWO'                  => chr(186),
-        'DOUBLE GT'                        => chr(187),
-        'QUARTER'                          => '¼',
-        'HALF'                             => '½',
-        'THREE QUARTERS'                   => '¾',
-        'INVERTED QUESTION'                => '¿',
-        'DIVISION'                         => '÷',
-        'HEART'                            => '♥',
-        'CLUB'                             => '♣',
-        'DIAMOND'                          => '♦',
-        'LARGE PLUS'                       => '┼',
-        'LARGE VERTICAL BAR'               => '│',
-        'LARGE OVERLINE'                   => '▔',
-        'LARGE UNDERLINE'                  => '▁',
-        'BULLET RIGHT'                     => '▶',
-        'BULLET LEFT'                      => '◀',
-        'SMALL BULLET RIGHT'               => '▸',
-        'SMALL BULLET LEFT'                => '◂',
-        'BIG BULLET RIGHT'                 => '►',
-        'BIG BULLET LEFT'                  => '◄',
-        'BULLET DOWN'                      => '▼',
-        'BULLET UP'                        => '▲',
-        'WEDGE TOP LEFT'                   => '◢',
-        'WEDGE TOP RIGHT'                  => '◣',
-        'WEDGE BOTTOM LEFT'                => '◥',
-        'WEDGE BOTTOM RIGHT'               => '◤',
-        'LOWER ONE EIGHT BLOCK'            => '▁',
-        'LOWER ONE QUARTER BLOCK'          => '▂',
-        'LOWER THREE EIGHTHS BLOCK'        => '▃',
-        'LOWER FIVE EIGTHS BLOCK'          => '▅',
-        'LOWER THREE QUARTERS BLOCK'       => '▆',
-        'LOWER SEVEN EIGHTHS BLOCK'        => '▇',
-        'LEFT SEVEN EIGHTHS BLOCK'         => '▉',
-        'LEFT THREE QUARTERS BLOCK'        => '▊',
-        'LEFT FIVE EIGHTHS BLOCK'          => '▋',
-        'LEFT THREE EIGHTHS BLOCK'         => '▍',
-        'LEFT ONE QUARTER BLOCK'           => '▎',
-        'LEFT ONE EIGHTH BLOCK'            => '▏',
-        'MEDIUM SHADE'                     => '▒',
-        'DARK SHADE'                       => ' ',
-        'UPPER ONE EIGHTH BLOCK'           => '▔',
-        'RIGHT ONE EIGHTH BLOCK'           => '▕',
-        'LOWER LEFT QUADRANT'              => '▖',
-        'LOWER RIGHT QUADRANT'             => '▗',
-        'UPPER LEFT QUADRANT'              => '▘',
-        'LEFT LOWER RIGHT QUADRANTS'       => '▙',
-        'UPPER LEFT LOWER RIGHT QUADRANTS' => '▚',
-        'LEFT UPPER RIGHT QUADRANTS'       => '▛',
-        'UPPER LEFT RIGHT QUADRANTS'       => '▜',
-        'UPPER RIGHT QUADRANT'             => '▝',
-        'UPPER RIGHT LOWER LEFT QUADRANTS' => '▞',
-        'RIGHT LOWER LEFT QUADRANTS'       => '▟',
-        'THICK VERTICAL BAR'               => chr(0xA6),
-        'THIN HORIZONTAL BAR'              => '─',
-        'THICK HORIZONTAL BAR'             => '━',
-        'THIN VERTICAL BAR'                => '│',
-        'MEDIUM VERTICAL BAR'              => '┃',
-        'THIN DASHED HORIZONTAL BAR'       => '┄',
-        'THICK DASHED HORIZONTAL BAR'      => '┅',
-        'THIN DASHED VERTICAL BAR'         => '┆',
-        'THICK DASHED VERTICAL BAR'        => '┇',
-        'THIN DOTTED HORIZONTAL BAR'       => '┈',
-        'THICK DOTTED HORIZONTAL BAR'      => '┉',
-        'MEDIUM DASHED VERTICAL BAR'       => '┊',
-        'THICK DASHED VERTICAL BAR'        => '┋',
-        'U250C'                            => '┌',
-        'U250D'                            => '┍',
-        'U250E'                            => '┎',
-        'U250F'                            => '┏',
-        'U2510'                            => '┐',
-        'U2511'                            => '┑',
-        'U2512'                            => '┒',
-        'U2513'                            => '┓',
-        'U2514'                            => '└',
-        'U2515'                            => '┕',
-        'U2516'                            => '┖',
-        'U2517'                            => '┗',
-        'U2518'                            => '┘',
-        'U2519'                            => '┙',
-        'U251A'                            => '┚',
-        'U251B'                            => '┛',
-        'U251C'                            => '├',
-        'U251D'                            => '┝',
-        'U251E'                            => '┞',
-        'U251F'                            => '┟',
-        'U2520'                            => '┠',
-        'U2521'                            => '┡',
-        'U2522'                            => '┢',
-        'U2523'                            => '┣',
-        'U2524'                            => '┤',
-        'U2525'                            => '┥',
-        'U2526'                            => '┦',
-        'U2527'                            => '┧',
-        'U2528'                            => '┨',
-        'U2529'                            => '┩',
-        'U252A'                            => '┪',
-        'U252B'                            => '┫',
-        'U252C'                            => '┬',
-        'U252D'                            => '┭',
-        'U252E'                            => '┮',
-        'U252F'                            => '┯',
-        'U2530'                            => '┰',
-        'U2531'                            => '┱',
-        'U2532'                            => '┲',
-        'U2533'                            => '┳',
-        'U2534'                            => '┴',
-        'U2535'                            => '┵',
-        'U2536'                            => '┶',
-        'U2537'                            => '┷',
-        'U2538'                            => '┸',
-        'U2539'                            => '┹',
-        'U253A'                            => '┺',
-        'U253B'                            => '┻',
-        'U235C'                            => '┼',
-        'U253D'                            => '┽',
-        'U253E'                            => '┾',
-        'U253F'                            => '┿',
-        'U2540'                            => '╀',
-        'U2541'                            => '╁',
-        'U2542'                            => '╂',
-        'U2543'                            => '╃',
-        'U2544'                            => '╄',
-        'U2545'                            => '╅',
-        'U2546'                            => '╆',
-        'U2547'                            => '╇',
-        'U2548'                            => '╈',
-        'U2549'                            => '╉',
-        'U254A'                            => '╊',
-        'U254B'                            => '╋',
-        'U254C'                            => '╌',
-        'U254D'                            => '╍',
-        'U254E'                            => '╎',
-        'U254F'                            => '╏',
-        'STAR'                             => '★',
-        'MAPLE LEAF'                       => '🍁',
-        'CHECK'                            => '✓',
-        'PIE'                              => 'π',
-        'TOP LEFT ROUNDED'                 => '╭',
-        'TOP RIGHT ROUNDED'                => '╮',
-        'BOTTOM RIGHT ROUNDED'             => '╯',
-        'BOTTOM LEFT ROUNDED'              => '╰',
-        'FULL FORWARD SLASH'               => '╱',
-        'FULL BACKWZARD SLASH'             => '╲',
-        'FULL X'                           => '╳',
-        'THIN LEFT HALF HYPHEN'            => '╴',
-        'THIN TOP HALF BAR'                => '╵',
-        'THIN RIGHT HALF HYPHEN'           => '╶',
-        'THIN BOTTOM HALF BAR'             => '╷',
-        'THICK LEFT HALF HYPHEN'           => '╸',
-        'THICK TOP HALF BAR'               => '╹',
-        'THICK RIGHT HALF HYPHEN'          => '╺',
-        'THICK BOTTOM HALF BAR'            => '╻',
-        'RIGHT TELESCOPE'                  => '╼',
-        'DOWN TELESCOPE'                   => '╽',
-        'LEFT TELESCOPE'                   => '╾',
-        'UP TELESCOPE'                     => '╿',
+        'HORIZONTAL RULE ORANGE'           => "\r" . $self->{'ansi_sequences'}->{'B_ORANGE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE PINK'             => "\r" . $self->{'ansi_sequences'}->{'B_PINK'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE RED'              => "\r" . $self->{'ansi_sequences'}->{'B_RED'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT RED'       => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_RED'} . clline . $self->{'ansi_sequences'}->{'RESET'}, 
         'HORIZONTAL RULE GREEN'            => "\r" . $self->{'ansi_sequences'}->{'B_GREEN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT GREEN'     => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_GREEN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE YELLOW'           => "\r" . $self->{'ansi_sequences'}->{'B_YELLOW'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT YELLOW'    => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_YELLOW'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE BLUE'             => "\r" . $self->{'ansi_sequences'}->{'B_BLUE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT BLUE'      => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_BLUE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE MAGENTA'          => "\r" . $self->{'ansi_sequences'}->{'B_MAGENTA'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT MAGENTA'   => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_MAGENTA'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE CYAN'             => "\r" . $self->{'ansi_sequences'}->{'B_CYAN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT CYAN'      => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_CYAN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
         'HORIZONTAL RULE WHITE'            => "\r" . $self->{'ansi_sequences'}->{'B_WHITE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
+        'HORIZONTAL RULE BRIGHT WHITE'     => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_WHITE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
     };
+	# Generate generic colors
     foreach my $count (0 .. 255) {
         $self->{'ansi_sequences'}->{"ANSI$count"}   = $esc . '38;5;' . $count . 'm';
         $self->{'ansi_sequences'}->{"B_ANSI$count"} = $esc . '48;5;' . $count . 'm';
@@ -371,6 +207,13 @@ sub new {
 			$self->{'ansi_sequences'}->{"B_GREY$num"} = $esc . '48;5;' . $count . 'm'; 
 		}
     }
+	# Generate symbols
+	foreach my $u (0x2000 .. 0x2B59) {
+		my $name = charnames::viacode($u);
+		unless ($name =~ /^(ZERO|LINE SEPARATOR|LEFT-TO-RIGHT|PARAGRAPH|POP |RIGHT-TO-LEFT|TRIGRAM|BRAILLE)/) {
+			$self->{'characters'}->{$name} = charnames::string_vianame($name);
+		}
+	}
 	bless($self,$class);
     return ($self);
 }
@@ -411,10 +254,16 @@ Simple usage and options documentation
 
 =item --B<tokens> or -B<y>
 
-Shows the most used tokens available.  A token is encapsulated within [% and %] (with one space on each side)
+Shows the most used tokens available.  A token is encapsulated within [% and %] (with at lease one space on each side)
 
 For example:
 
+=item --B<symbols> or -B<s> [search]
+
+Similar to "tokens", but instead shows special symbol character tokens.
+
+You may also add a search string to shorten the list.
+
 =back
 
 =over 8
@@ -511,4 +360,25 @@ B<RESET> changes output text to normal.
  BRIGHT B_CYAN    = Bright cyan
  BRIGHT B_WHITE   = Bright white
 
+=head2 HORIZONAL RULES
+
+Makes a solid blank line, the full width of the screen with the selected background color
+
+ HORIZONTAL RULE RED             = A solid line of red background
+ HORIZONTAL RULE GREEN           = A solid line of green background
+ HORIZONTAL RULE YELLOW          = A solid line of yellow background
+ HORIZONTAL RULE BLUE            = A solid line of blue background
+ HORIZONTAL RULE MAGENTA         = A solid line of magenta background
+ HORIZONTAL RULE CYAN            = A solid line of cyan background
+ HORIZONTAL RULE PINK            = A solid line of hot pink background
+ HORIZONTAL RULE ORANGE          = A solid line of orange background
+ HORIZONTAL RULE WHITE           = A solid line of white background
+ HORIZONTAL RULE BRIGHT RED      = A solid line of bright red background
+ HORIZONTAL RULE BRIGHT GREEN    = A solid line of bright green background
+ HORIZONTAL RULE BRIGHT YELLOW   = A solid line of bright yellow background
+ HORIZONTAL RULE BRIGHT BLUE     = A solid line of bright blue background
+ HORIZONTAL RULE BRIGHT MAGENTA  = A solid line of bright magenta background
+ HORIZONTAL RULE BRIGHT CYAN     = A solid line of bright cyan background
+ HORIZONTAL RULE BRIGHT WHITE    = A solid line of bright white background
+
 =cut
